@@ -7,7 +7,7 @@
 # Filename:               other_tests/test_workflow_integration.py
 # Purpose:                Integration tests for the WorkflowManager
 #
-# Copyright (C) 2013 Christopher Antila
+# Copyright (C) 2013, 2014 Christopher Antila, Alexander Morgan
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -179,6 +179,15 @@ class NGramsTests(TestCase):
     EXPECTED_7 = pandas.Series({u'4 1 5': 1, u'5 1 4': 1, u'6 2 6': 1, u'6 -2 6': 1, u'8 -2 10': 1,
                                 u'10 2 8': 1, u'3 2 2': 1, u'2 -2 3': 1, u'5 -2 6': 1, u'6 2 5': 1,
                                 u'3 -2 5': 1, u'5 2 3': 1})
+    # EXPECTED_9 is the result of "interval n-grams" on Kyrie_short.krn with voices 1 and 3, and
+    # I counted it by hand!
+    EXPECTED_9a = pandas.Series({'8 3 6': 1, '6 zamboni 6': 1, '6 -2 8': 1, '5 zamboni 5': 1,
+                                 '5 4 3': 1, '3 zamboni 3': 1, '3 -3 6': 1})
+    EXPECTED_9b = pandas.Series({'P8 M3 m6': 1, 'P5 P4 M3': 1, 'P5 P1 P5': 1, 'M6 P1 M6': 1,
+                                 'M6 -M2 P8': 1, 'M3 P1 M3': 1, 'M3 -m3 M6': 1})
+    EXPECTED_9c = pandas.Series({'8 3 6': 1, '6 1 6': 1, '6 -2 8': 1, '5 4 3': 1, '5 1 5': 1,
+                                 '3 1 3': 1, '3 -3 6': 1})
+
 
     def test_ngrams_1(self):
         # test the two highest voices of bwv77; 2-grams
@@ -186,6 +195,7 @@ class NGramsTests(TestCase):
         test_wm.load('pieces')
         test_wm.settings(0, 'voice combinations', '[[0, 1]]')
         test_wm.settings(0, 'n', 2)
+        test_wm.settings(0, 'continuer', '_')
         actual = test_wm.run('interval n-grams')
         exp_ind = list(NGramsTests.EXPECTED_1.index)
         act_ind = list(actual.index)
@@ -200,6 +210,7 @@ class NGramsTests(TestCase):
         test_wm.load('pieces')
         test_wm.settings(0, 'voice combinations', 'all pairs')
         test_wm.settings(0, 'n', 5)
+        test_wm.settings(0, 'continuer', '_')
         actual = test_wm.run('interval n-grams')[:10]
         exp_ind = list(NGramsTests.EXPECTED_2.index)
         act_ind = list(actual.index)
@@ -229,6 +240,7 @@ class NGramsTests(TestCase):
         test_wm.settings(0, 'voice combinations', 'all')
         test_wm.settings(0, 'n', 2)
         test_wm.settings(None, 'simple intervals', True)
+        test_wm.settings(0, 'continuer', '_')
         actual = test_wm.run('interval n-grams')[:10]
         exp_ind = list(NGramsTests.EXPECTED_4.index)
         act_ind = list(actual.index)
@@ -243,6 +255,7 @@ class NGramsTests(TestCase):
         test_wm.settings(0, 'voice combinations', 'all')
         test_wm.settings(None, 'include rests', False)
         test_wm.load('pieces')
+        test_wm.settings(0, 'continuer', '_')
         actual = test_wm.run('interval n-grams')
         exp_ind = list(NGramsTests.EXPECTED_5.index)
         act_ind = list(actual.index)
@@ -257,6 +270,7 @@ class NGramsTests(TestCase):
         test_wm.settings(0, 'voice combinations', 'all')
         test_wm.settings(None, 'include rests', True)
         test_wm.load('pieces')
+        test_wm.settings(0, 'continuer', '_')
         actual = test_wm.run('interval n-grams')
         exp_ind = list(NGramsTests.EXPECTED_6.index)
         act_ind = list(actual.index)
@@ -293,6 +307,56 @@ class NGramsTests(TestCase):
             self.assertTrue(ind_item in act_ind)
             self.assertEqual(NGramsTests.EXPECTED_7[ind_item], actual[ind_item])
 
+    def test_ngrams_9a(self):
+        # test the calculation of horizontal intervals when the lower voice is sustained
+        # longer than the offset interval. A custom string is passed for horizontal
+        # unisons resulting from a sustained lower voice. Regression test for:
+        # https://github.com/ELVIS-Project/vis/issues/305
+        test_wm = WorkflowManager(['vis/tests/corpus/Kyrie_short.krn'])
+        test_wm.load()
+        test_wm.settings(0, 'voice combinations', '[[1,3]]')
+        test_wm.settings(0, 'n', 2)
+        test_wm.settings(0, 'offset interval', 2.0)
+        test_wm.settings(0, 'continuer', 'zamboni')
+        actual = test_wm.run('interval n-grams')
+        exp_ind = list(NGramsTests.EXPECTED_9a.index)
+        act_ind = list(actual.index)
+        self.assertEqual(len(exp_ind), len(act_ind))
+        for ind_item in exp_ind:
+            self.assertTrue(ind_item in act_ind)
+            self.assertEqual(NGramsTests.EXPECTED_9a[ind_item], actual[ind_item])
+
+    def test_ngrams_9b(self):
+        # same as 9a but tests functionality of 'dynamic quality setting of continuer
+        # when 'interval quality' is set to True.
+        test_wm = WorkflowManager(['vis/tests/corpus/Kyrie_short.krn'])
+        test_wm.load()
+        test_wm.settings(0, 'voice combinations', '[[1,3]]')
+        test_wm.settings(0, 'n', 2)
+        test_wm.settings(0, 'offset interval', 2.0)
+        test_wm.settings(0, 'interval quality', True)
+        actual = test_wm.run('interval n-grams')
+        exp_ind = list(NGramsTests.EXPECTED_9b.index)
+        act_ind = list(actual.index)
+        self.assertEqual(len(exp_ind), len(act_ind))
+        for ind_item in exp_ind:
+            self.assertTrue(ind_item in act_ind)
+            self.assertEqual(NGramsTests.EXPECTED_9b[ind_item], actual[ind_item])
+
+    def test_ngrams_9c(self):
+        # same as 9b but 'interval quality' is set to False (by default).
+        test_wm = WorkflowManager(['vis/tests/corpus/Kyrie_short.krn'])
+        test_wm.load()
+        test_wm.settings(0, 'voice combinations', '[[1,3]]')
+        test_wm.settings(0, 'n', 2)
+        test_wm.settings(0, 'offset interval', 2.0)
+        actual = test_wm.run('interval n-grams')
+        exp_ind = list(NGramsTests.EXPECTED_9c.index)
+        act_ind = list(actual.index)
+        self.assertEqual(len(exp_ind), len(act_ind))
+        for ind_item in exp_ind:
+            self.assertTrue(ind_item in act_ind)
+            self.assertEqual(NGramsTests.EXPECTED_9c[ind_item], actual[ind_item])
 
 #-------------------------------------------------------------------------------------------------#
 # Definitions                                                                                     #
